/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8310_CMPSUP_IMPOSTO_INCIDE_PRODAF                                    */
/*                                                                            */
/* Descrio:                                                                 */
/* Busca e insere os impostos que incidem em um determiando produto           */
/* da AF                                                                      */
/*                                                                            */
/* Criao:                                                                   */
/* 27/04/2000 - Yoris L. de Souza                                             */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* PARAMETROS:                                                                */
/*                                                                            */
/******************************************************************************/
/* @D:\SQL\CALECOMP\8040_CMPSTP_SEM_DATA_ENTR_MES.SQL     */
/* @H:\SISTEMAS\DBA\SQL\ORACLE\8340_CMPSTP_IMPOSTO_INCIDE_PRODAF.SQL */
/******************************************************************************/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'IMPOSTO_INCIDE_PRODAF'  AND
	        TYPE = 'P' 			        AND
	        U.UID = O.UID                    AND
	        U.NAME = USER)

  DROP PROCEDURE IMPOSTO_INCIDE_PRODAF
  GO

CREATE  PROCEDURE IMPOSTO_INCIDE_PRODAF
                     @P_CDFILDEST   VARCHAR(4),
                     @P_CDFILLANC   VARCHAR(4),
                     @P_NRAUTOFORN  VARCHAR(10),
                     @P_CDPRODUTO   VARCHAR(10),
                     @P_CDMARCA     VARCHAR(5),
                     @P_DTPROGENTAF DATETIME

AS
DECLARE @V_TIPOOPER   VARCHAR(02);
DECLARE @V_CDEMPRESA  VARCHAR(02);
DECLARE @V_CDINSCESTA VARCHAR(16);
DECLARE @V_CDARVPROD  VARCHAR(10);

DECLARE @V_CDIMPOSTO       VARCHAR(2);
DECLARE @V_INCID_CDIMPOSTO VARCHAR(2);
DECLARE @V_INCID_CDFISCAL  VARCHAR(1);

BEGIN

 SELECT
   @V_CDEMPRESA = MAX(AUTOFORNE.CDEMPRESA)
 FROM AUTOFORNE
 WHERE
   AUTOFORNE.CDFILDEST  = @P_CDFILDEST  AND
   AUTOFORNE.CDFILLANC  = @P_CDFILLANC  AND
   AUTOFORNE.NRAUTOFORN = @P_NRAUTOFORN;

 SELECT @V_CDINSCESTA = MAX(CDINSCESTA)
 FROM FILIAL
 WHERE
   CDFILIAL  = @P_CDFILDEST AND
   CDEMPRESA = @V_CDEMPRESA;

 SELECT @V_TIPOOPER = ISNULL(MAX(CDTIPOOPER), '01')
 FROM
    PARCMPSUP,
    FILIAL
 WHERE
    (FILIAL.CDFILIAL    = @P_CDFILDEST) AND
    (PARCMPSUP.CDFILIAL = ISNULL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL));
    
 DECLARE C_IMPOSTO CURSOR FOR
 SELECT DISTINCT (CDIMPOSTO) AS CDIMPOSTO
 FROM INCIDENCIA;

 OPEN C_IMPOSTO;

 FETCH NEXT FROM C_IMPOSTO INTO @V_CDIMPOSTO;

 WHILE (@@FETCH_STATUS = 0)
 BEGIN
    SET @V_CDARVPROD = NULL;
    SELECT @V_CDARVPROD = MAX(PRODUTO.CDARVPROD)
    FROM INCIDENCIA, PRODUTO, PRODUTO P
       WHERE (INCIDENCIA.IDENTRSAIDIN = 'E') AND
             (INCIDENCIA.CDEMPRESA    = @V_CDEMPRESA) AND
             (INCIDENCIA.CDTIPOOPER   = @V_TIPOOPER) AND
             (INCIDENCIA.CDIMPOSTO    = @V_CDIMPOSTO) AND
             (INCIDENCIA.CDINSCESTA   = RTRIM(@V_CDINSCESTA)) AND
             (INCIDENCIA.CDPRODUTO    = PRODUTO.CDPRODUTO) AND
             (P.CDPRODUTO = @P_CDPRODUTO) AND
             (CHARINDEX(RTRIM(PRODUTO.CDARVPROD), P.CDARVPROD) = 1 OR PRODUTO.CDARVPROD IS NULL);

    IF NOT (@V_CDARVPROD IS NULL)
    BEGIN

      DECLARE C_INCIDENCIA CURSOR FOR
      SELECT INCIDENCIA.CDIMPOSTO, CDFISCAL
      FROM INCIDENCIA, PRODUTO
       WHERE (INCIDENCIA.IDENTRSAIDIN = 'E') AND
             (INCIDENCIA.CDEMPRESA    = @V_CDEMPRESA) AND
             (INCIDENCIA.CDTIPOOPER   = @V_TIPOOPER) AND
             (INCIDENCIA.CDIMPOSTO    = @V_CDIMPOSTO) AND
             (INCIDENCIA.CDINSCESTA   = RTRIM(@V_CDINSCESTA)) AND
             (INCIDENCIA.CDPRODUTO    = PRODUTO.CDPRODUTO) AND
             (PRODUTO.CDARVPROD       = @V_CDARVPROD);

      OPEN C_INCIDENCIA;
      FETCH NEXT FROM C_INCIDENCIA INTO @V_INCID_CDIMPOSTO,
                                        @V_INCID_CDFISCAL

      WHILE (@@FETCH_STATUS = 0)
      BEGIN
        INSERT INTO IMPITMAF
       (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, CDMARCA,
        DTPROGENTAF, CDIMPOSTO,VRALIQITMAF, VRIMPITMAF, CDFISCITMAF,VRADIMPAF)
        VALUES
       (@P_CDFILDEST, @P_CDFILLANC, @P_NRAUTOFORN, @P_CDPRODUTO, @P_CDMARCA,
        @P_DTPROGENTAF, @V_INCID_CDIMPOSTO,0, 0,@V_INCID_CDFISCAL,0);

        FETCH NEXT FROM C_INCIDENCIA INTO @V_INCID_CDIMPOSTO,
                                          @V_INCID_CDFISCAL
      END;
      CLOSE C_INCIDENCIA;
      DEALLOCATE C_INCIDENCIA;
    END
    ELSE IF (@V_CDARVPROD IS NULL)
    BEGIN

      DECLARE C_INCIDNULL CURSOR FOR
      SELECT INCIDENCIA.CDIMPOSTO, CDFISCAL
      FROM INCIDENCIA
       WHERE (INCIDENCIA.IDENTRSAIDIN = 'E') AND
             (INCIDENCIA.CDEMPRESA    = @V_CDEMPRESA) AND
             (INCIDENCIA.CDTIPOOPER   = @V_TIPOOPER) AND
             (INCIDENCIA.CDIMPOSTO    = @V_CDIMPOSTO) AND
             (INCIDENCIA.CDINSCESTA   = RTRIM(@V_CDINSCESTA)) AND
             (INCIDENCIA.CDPRODUTO IS NULL);

      OPEN C_INCIDNULL;
      FETCH NEXT FROM C_INCIDNULL  INTO @V_INCID_CDIMPOSTO,
                                        @V_INCID_CDFISCAL
      WHILE (@@FETCH_STATUS = 0)
      BEGIN

        INSERT INTO IMPITMAF
       (CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, CDMARCA,
        DTPROGENTAF, CDIMPOSTO,VRALIQITMAF, VRIMPITMAF, CDFISCITMAF,VRADIMPAF)
        VALUES
       (@P_CDFILDEST, @P_CDFILLANC, @P_NRAUTOFORN, @P_CDPRODUTO, @P_CDMARCA,
        @P_DTPROGENTAF, @V_INCID_CDIMPOSTO,0,0,@V_INCID_CDFISCAL,0);

        FETCH NEXT FROM C_INCIDNULL  INTO @V_INCID_CDIMPOSTO,
                                          @V_INCID_CDFISCAL
       END;
       CLOSE C_INCIDNULL;
       DEALLOCATE C_INCIDNULL;
    END;
    FETCH NEXT FROM C_IMPOSTO INTO @V_CDIMPOSTO;
 END;
 CLOSE C_IMPOSTO;
 DEALLOCATE C_IMPOSTO;
END;
GO

